Package: TreeDimensionTest
Type: Package
Title: Trajectory Presence and Heterogeneity in Multivariate Data
Version: 0.0.3
Date: 2026-07-18
Authors@R: c(
    person("Lovemore", "Tenha", , "ltenha@nmsu.edu", role = "aut",
           comment = c(ORCID = "0000-0001-9705-2023")),
    person("Joe", "Song", , "joemsong@nmsu.edu", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-6883-6547"))
  )
Author: Lovemore Tenha [aut] (ORCID: <https://orcid.org/0000-0001-9705-2023>),
  Joe Song [aut, cre] (ORCID: <https://orcid.org/0000-0002-6883-6547>)
Maintainer: Joe Song <joemsong@nmsu.edu>
Description: Testing for trajectory presence and heterogeneity on
 multivariate data. Two statistical methods (Tenha & Song 2022) 
 <doi:10.1371/journal.pcbi.1009829> are implemented. The tree dimension
 test quantifies the statistical evidence for trajectory presence. The
 subset specificity measure summarizes pattern heterogeneity using the
 minimum subtree cover. There is no user tunable parameters for either
 method. Examples are included to illustrate how to use the methods on 
 single-cell data for studying gene and pathway expression dynamics and
 pathway expression specificity.
License: LGPL (>= 3)
Imports: fitdistrplus, igraph, nFactors, Rcpp (>= 1.0.2), RColorBrewer,
        Rdpack
LinkingTo: Rcpp
Encoding: UTF-8
Suggests: knitr, rmarkdown, testthat
VignetteBuilder: knitr
NeedsCompilation: yes
RdMacros: Rdpack
Depends: mlpack (>= 4.8.0)
Config/roxygen2/version: 8.0.0
Packaged: 2026-07-18 07:18:59 UTC; joesong
Repository: CRAN
Date/Publication: 2026-07-18 22:40:14 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-07-19 03:28:58 UTC; unix
Archs: TreeDimensionTest.so.dSYM

# Generated by roxygen2: do not edit by hand

S3method(plot,treedim)
export(compute.stats)
export(empirical.distributions)
export(separability)
export(test.trajectory)
import(RColorBrewer)
import(fitdistrplus)
import(igraph)
import(nFactors)
importFrom(Rcpp,evalCpp)
importFrom(Rdpack,reprompt)
importFrom(graphics,legend)
importFrom(graphics,plot)
importFrom(mlpack,emst)
importFrom(stats,cov)
importFrom(stats,dist)
importFrom(stats,plnorm)
importFrom(stats,prcomp)
importFrom(stats,rnorm)
useDynLib(TreeDimensionTest)

---
title: The 'TreeDimensionTest' R package
bibliography: inst/REFERENCES.bib
---
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)

### Overview

The package offers tests for trajectory presence and heterogeneity on multivariate data. Two statistical methods (Tenha and Song, 2022) are implemented. The tree dimension test quantifies the statistical evidence for trajectory presence. The subset specificity measure summarizes pattern heterogeneity using the minimum subtree cover. There is no user tunable parameters for either method. Examples are included to illustrate how to use the methods on single-cell data for studying gene and pathway expression dynamics and pathway expression specificity.
 
### To download and install the package

```{r}
install.packages("DimensionTreeTest")
```

### Examples

See the package vignette.

### Citing the package

Tenha L, Song M (2022). “Inference of trajectory presence by
tree dimension and subset specificity by subtree cover.” _PLOS
Computational Biology_, *18*(2), e1009829. doi:
10.1371/journal.pcbi.1009829 (URL:
<https://doi.org/10.1371/journal.pcbi.1009829>).

## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(warning = FALSE, message = FALSE,
  collapse = TRUE, cache = FALSE, comment = "#>", out.width = "65%")

## -----------------------------------------------------------------------------
require(TreeDimensionTest)

data_path=system.file('extdata', 'bifurcating_7.rds', package = 'TreeDimensionTest')

input = readRDS(data_path)

## -----------------------------------------------------------------------------
res = test.trajectory(input)

## ----echo=FALSE---------------------------------------------------------------
knitr::kable(unlist(res[-7], recursive = FALSE), col.names = "Test results contained in `res`")

## -----------------------------------------------------------------------------
plot(res, node.size=12, node.col="mediumseagreen", 
     main = paste0("Trajectory presence\np-value = ",
                   format.pval(res$p.value, digit=2)))
pc=prcomp(input)
plot(pc$x[,c(1:2)], xlab="PC1", ylab="PC2", cex=1,
     sub="Principal components", col="mediumseagreen",
     main = paste0("Trajectory presence\np-value = ",
                   format.pval(res$p.value, digit=2), 
                   "\n(n = ", nrow(input), ")")
    )

## -----------------------------------------------------------------------------
res = test.trajectory(input, dim.reduction = "pca", MST = "exact")

## ----echo=FALSE---------------------------------------------------------------
knitr::kable(unlist(res[-7], recursive = FALSE), col.names = "Test results contained in `res`")

## -----------------------------------------------------------------------------
n = 100
mat = cbind(rnorm(n), rnorm(n))
res = test.trajectory(mat, dim.reduction = "none")

## ----echo=FALSE---------------------------------------------------------------
knitr::kable(unlist(res[-7]), col.names = "Test results contained in `res`")

## -----------------------------------------------------------------------------
plot(res, node.size=12, 
     main = paste0("Trajectory presence\np-value = ",
                   format.pval(res$p.value, digit=2)))
plot(mat, col="orange", pch=2, cex=0.5, xlab="Dim 1", ylab="Dim 2",
     main=paste0("Trajectory presence\np-value = ", 
                format.pval(res$p.value, digit=2), 
                "\n(n = ", n, ")")
     )

## -----------------------------------------------------------------------------
res = compute.stats(mat, MST="boruvka", dim.reduction = "none")

## ----echo=FALSE---------------------------------------------------------------
knitr::kable(unlist(res[-5]), col.names = "Results contained in `res`")

## -----------------------------------------------------------------------------
#Random data
mat = cbind(rnorm(200), rnorm(200))

#Labels for the samples in the data
labels = c(rep("L1", 93), rep("L2",78), rep("L3",29))

#Color vector of samples, each unique color correspods with unique label
cols = c(rep("orange", 93), rep("mediumseagreen", 78), rep("purple", 29))

#Compute separability of samples in mat
res = separability(mat, labels)

## -----------------------------------------------------------------------------
knitr::kable(res$label_separability, col.names = "Label separability")

## -----------------------------------------------------------------------------
#Plots an MST of the data, with samples of the same label highlighted by same color
# plotTree(mat, labels, node.size = 12, node.col = cols, 
#   main = paste("Low seperability", format(res$overall_separability, digits = 3)), 
#   legend.cord=c(-2.1,0.9)
# )

plot(res,node.size = 12, node.col = cols, 
  main = paste("Low seperability", format(res$overall_separability, digits = 3)), legend.cord=c(-2.1,0.9))

## -----------------------------------------------------------------------------
mat = rbind(
  cbind(rnorm(93,mean=20), rnorm(93, mean=20)),
  cbind(rnorm(78,mean=5), rnorm(78,mean=5)),
  cbind(rnorm(29, mean=50), rnorm(29, mean=50)))
labels = c(rep("L1", 93), rep("L2",78), rep("L3",29))
res = separability(mat, labels)


## -----------------------------------------------------------------------------
knitr::kable(res$label_separability, col.names = " Label separability")

## -----------------------------------------------------------------------------
#Color vector of samples corresponding to labels
cols = c(rep("orange", 93), rep("mediumseagreen", 78), rep("purple", 29))

# plotTree(
#   mat,labels, node.size=12, node.col = cols, 
#   main = paste("High seperability", format(res$overall_separability, digits = 3)), 
#   legend.cord=c(-1.9,0.9))


plot(res,node.size = 12, node.col = cols, 
  main = paste("High seperability", format(res$overall_separability, digits = 3)), legend.cord=c(-2.1,0.9))

## -----------------------------------------------------------------------------
#Loading calcium signaling pathway data from Mouse
#This is Mouse development RNA-seq data spanned by the geneset fo calcium signaling pathway
#Rows are genes and columns are samples.

file.rdata=system.file('extdata', 'calcium_pathway_data.rdata', package = 'TreeDimensionTest')
load(file=file.rdata)

#loading color vector of samples by label type; mouse_cols
file.rdata=system.file('extdata', 'mouse_cols.rdata', package = 'TreeDimensionTest')
load(file=file.rdata)

#Labels of the samples are the column names of the data, which are names of tissue types.
labels = colnames(calcium_pathway_data)

res = separability(t(calcium_pathway_data), labels)

#Separabiltiy for each tissue type as well as the overall separability. High separability depicts high tissue specificity.


# plotTree(
#   t(calcium_pathway_data), labels, node.col=mouse_cols,node.size=12, 
#   main = paste("Calcium signaling pathway\nTissue specificity", 
#                format(res$overall_separability, digits = 3)), 
#   legend.cord=c(-1.9,-1.3))

plot(res,node.size = 12, node.col=mouse_cols,
 main = paste("Calcium signaling pathway\nTissue specificity", 
               format(res$overall_separability, digits = 3)), legend.cord=c(-1.9,-1.3))

## -----------------------------------------------------------------------------
knitr::kable(res$label_separability, col.names = "Calcium signaling pathway tissue specificity")

## -----------------------------------------------------------------------------
#Loading ribosome pathway data from Mouse
file.rdata=system.file('extdata', 'ribosome_pathway_data.rdata', package = 'TreeDimensionTest')
load(file=file.rdata)

#loading color vector of samples by label type; mouse_cols
file.rdata=system.file('extdata', 'mouse_cols.rdata', package = 'TreeDimensionTest')
load(file=file.rdata)

# ribsome_pathway_data is RNA-seq data with rows as genes and columns as samples
labels = colnames(ribosome_pathway_data)
res = separability(t(ribosome_pathway_data), labels)
plot(
  res, node.col= mouse_cols,
  node.size=12, 
  main = paste("Ribosome pathway\nTissue specificity",
               format(res$overall_separability, digits = 3)), 
  legend.cord=c(-1.9,-1.3))

## -----------------------------------------------------------------------------
knitr::kable(res$label_separability, col.names = "Ribosome pathway tissue specificity")

#' Tree Dimension Test
#'
#' Computes the statistical significance for the presence of trajectory
#' in multivariate data.
#'
#' @param x matrix of input data. Rows as observations and columns as
#'  features.
#' @param perm number of simulations to compute null distribution
#'  parameters by maximum likelihood estimation.
#' @param MST the MST algorithm to be used in test. There are two
#'  options: "exact" MST and "boruvka" which is approximate but faster
#'  for large samples.
#' @param dim.reduction string parameter with value "pca" to perform
#'  dimensionality reduction or "none" to not perform dimensionality
#'  reduction before the test.
#'
#' @details If the input data is already after dimension reduction, use
#' \code{dim.reduction="none"}. The method is described in
#' \insertCite{Tenha:2022}{TreeDimensionTest}.
#'
#' @references
#' \insertAllCited{}
#'
#' @return A list with the following components:
#' \itemize{
#'  \item tdt_measure The tree dimension value for the given input data
#'  \item statistic  The S statistic calculated on the input data. S statistic is derived from tree dimension
#'  \item tdt_effect Effect size for tree dimension
#'  \item leaves Number of leaf/degree1 vertices in the MST  of the data
#'  \item diameter The tree diameter of MST, where each edge is of unit length
#'  \item p.value The pvalue for the S statistic. Pvalue measures presence of trajectory in input x.
#'  \item original_dimension If "pca" is selected, the number of dimensions in the original dataset
#'  \item pca_components If "pca" is selected, the number of pca components selected after dimensionality reduction
#'  \item mst A vector of edges of the mst computed on x. Length of vector is always even.
#' }
#'
#' @importFrom Rcpp evalCpp
#' @importFrom graphics plot legend
#' @importFrom stats dist plnorm rnorm cov prcomp
#' @importFrom mlpack emst
#' @import nFactors
#' @importFrom Rdpack reprompt
#'
#' @export
#' @useDynLib TreeDimensionTest

test.trajectory <- function(
  x, perm=100, MST=c("boruvka", "exact"),
  dim.reduction=c("pca", "none")
)
{

  #Error checking argument x
  if(missing(x)) stop("Argument x is required.")
  if(!is.matrix(x)) stop("Argument x should be a matrix.")
  if(perm < 0 ) stop("Argument perm should be greater thatn 0.")

  MST <- match.arg(MST)
  dim.reduction <- match.arg(dim.reduction)
  original_dimension = ncol(x)
  ###Apply pca if dim.reduction="pca"

  if(dim.reduction=="pca")
  {
    pc = prcomp(x)

    if(length(pc$sdev) >= 6) #nCng works with at least 6 variables
    {
      cmps = nCng(pc$sdev)
      x = pc$x[,c(1:cmps$nFactors)]
    }

    #if variables are less than 6, use all components
    else
    {
      x = pc$x
    }
  }


  #Getting null distribution
  dist = computeDists(x, perm, nrow(x), randomize.data, MST)


  #Getting observed statistic and tree dimension
  estimates = getStatistics(x, nrow(x), MST, T)

  #Fitting lognormal and calculating pvalue for s statistic
  fit = fitdist(dist, distr="lnorm", start = list(meanlog=1, sdlog =1))


  #Output result
  result = list()
  result$tdt_measure = estimates$td
  result$statistic = estimates$stat
  result$tdt_effect = estimates$effect
  result$leaves = estimates$leafs
  result$diameter = estimates$diameter
  result$p.value = plnorm(estimates$stat, meanlog = fit$estimate['meanlog'] , sdlog = fit$estimate['sdlog'], lower.tail = F)
  result$mst = estimates$mst

  #Number of dimensions before and after pca dimensionality reduction added to result
  if(dim.reduction=="pca")
  {
    result$original_dimension = original_dimension
    result$pca_components = ncol(x)
  }

  class(result)="treedim"

  return(result)
}

#' Empirical Null Distribution of Tree Dimension Test
#'
#' Computes empirical null distribution of S statistic and parameters
#'  for lognormal approximation for input of size rows * columns using
#'  multivariate normal randomization

#' @param rows number of rows for data representing null case. Rows
#'  represent sample size.
#' @param cols number of columns for data representing null case.
#'  Columns represent variables.
#' @param perm number of simulations to compute null distribution.
#'  Default is 100.
#' @param MST name of MST to be used in computing distribution. There
#'  are two options; "exact" MST and "boruvka" which is faster for
#'  large samples

#' @return A list with the following components:
#' \itemize{
#'  \item dist       A vector with null distribution of s statistic
#'  \item meanlog    The meanlog parameter estimation for the lognormal distribution on empirical null distribution S.
#'  \item sdlog      The sdlog parameter estimation for lognormal distribution on empirical null distribution of S.
#' }
#' @import fitdistrplus
#' @export

empirical.distributions <- function(
  rows, cols, perm=100, MST=c("boruvka", "exact")
)
{
  if(missing(rows)) stop("Argument rows is required.")
  if(missing(cols)) stop("Argument cols is required.")
  if(perm < 0 ) stop("Argument perm should be greater thatn 0.")
  sample_size = rows
  x=randomize.data(rows,cols)
  distbns = computeDists(x, perm, sample_size, randomize.data, MST)


  #Fitting lognormal
  fit = fitdist(distbns, distr="lnorm", start = list(meanlog=1, sdlog =1))
  result = list()
  result$dist = distbns
  result$meanlog = fit$estimate['meanlog']
  result$sdlog = fit$estimate['sdlog']
  return(result)
}




#' Visualizing Euclidean Minimum Spanning Trees
#'
#' Plots an Euclidean minimum spanning tree from given input data.

#' @param x An object of type "treedim"; returned from test.trajectory, compute.stats or separability
#' @param ... ignore
#' @param node.col vector of colors for the observations in x (vertices)
#' @param node.size numerical value to represent size of nodes in the plot
#' @param main title for the plot
#' @param legend.cord vector of the xy coordinates for the legend c(x,y)
#' @return result plots a minimum spanning tree for input data x
#' @import igraph
#' @import RColorBrewer
#' @rdname plot.test
#' @export

plot.treedim <-  function(x,...,
  node.col="orange",
  node.size=5, main="MST plot",
  legend.cord=c(-1.2,1.1))
{

  if(missing(x)) stop("Argument x is required.")

  #Create an igraph object
  g = graph(c())

  #Create graph object using edgelist mst, from x

   if(is.list(x$mst))
    g=igraph::graph(x$mst$edges, directed = FALSE)

  else
    g=igraph::graph(x$mst, directed = FALSE)


  #coloring; if object x is from separability
  if(is.list(x$mst))
  {
    if(length(node.col)!= length(unique(x$mst$edges)))
    {

      #coloring
      qual_col_pals = brewer.pal.info[brewer.pal.info$category == 'qual',]
      col_vector = unlist(mapply(brewer.pal, qual_col_pals$maxcolors, rownames(qual_col_pals)))

      unique_labels = unique(x$mst$labels)
      cols = vector(length=length(x$mst$labels))
      j=1
      for(i in unique_labels)
      {
        cols[which(x$mst$labels %in% i)]=j
        j=j+1
      }

      node.col = col_vector[cols]
    }
  }

  plot.igraph(g, vertex.size=node.size ,vertex.color = node.col ,vertex.label="",main=main ,cex.main=0.03,layout=layout_components, font.main=0.7)

  #If x is treedim object from separability
  if(is.list(x$mst))
    legend(legend.cord[1], legend.cord[2], legend = unique(x$mst$labels) , col= unique(node.col), lwd=4, cex=0.6)

}



#Multivariate standard normal
randomize.data = function(sample, dim, iter, max_iter)
{
  #for reproducibility of null distribution
  set.seed(sample+dim+iter+max_iter)
  ran = rnorm(sample)

  for(i in c(2:dim))
  {
    ran = cbind(ran , rnorm(sample))
  }
  set.seed(NULL)
  return(ran)
}



#Get edges in correct format

# get_edges = function(m) {
#   edges = vector()
#
#   rows = sample(nrow(m))
#   cols = sample(ncol(m))
#   for(i in rows)
#   {
#     for(j in cols)
#     {
#       if(i<j && m[i,j])
#       {
#         edges = c(edges, i, j)}
#       }
#   }
#   return(edges)
#}


#' Tree Dimension Test Related Statistics
#'
#' Computes tree dimension measure, tree dimension test effect,
#' number leafs and tree diameter from MST of a given dataset

#' @param x matrix of input data. Rows as observations and columns as features
#' @param MST name of MST to be used in test. There are 2 options; "exact" MST and "boruvka" which is faster for large samples
#' @param dim.reduction string parameter with value "pca" to perform dimensionality reduction or "none" to not perform dimensionality reduction
#' @return A list with the following components:
#' \itemize{
#'  \item tdt_measure The tree dimension value for the given input data
#'  \item tdt_effect Effect size for tree dimension
#'  \item leaves Number of leaf/degree1 vertices in the MST  of the data
#'  \item diameter The tree diameter of MST, where each edge is of unit length
#'  \item original_dimension If "pca" is selected, the number of dimensions in the original dataset
#'  \item pca_components If "pca" is selected, the number of pca components selected after dimensionality reduction
#'  \item mst A vector of edges of the mst computed on x. Length of vector is always even.

#'  }
#' @export


compute.stats <- function(
  x, MST=c("boruvka", "exact"),
  dim.reduction=c("pca", "none")
)
{
  MST <- match.arg(MST)
  dim.reduction <- match.arg(dim.reduction)
  original_dimension = nrow(x)

  if(dim.reduction=="pca")
  {
    pc = prcomp(x)

    if(length(pc$sdev) >= 6) #nCng works with at least 6 variables
    {
      cmps = nCng(pc$sdev)
      x = pc$x[,c(1:cmps$nFactors)]
    }

    #if variables are less than 6, use all components
    else
    {
      x = pc$x
    }
  }
  estimates = getStatistics(x, nrow(x), MST,T)
  result = list()
  result$tdt_measure = estimates$td
  result$tdt_effect = estimates$effect
  result$leaves = estimates$leafs
  result$diameter = estimates$diameter
  result$mst = estimates$mst

  #Number of dimensions before and after pca dimensionality reduction added to result
  if(dim.reduction=="pca")
  {
    result$original_dimension = original_dimension
    result$pca_components = ncol(x)
  }

  class(result)="treedim"

  return (result)
}


#' Separability of Labeled Data Points
#'
#' Computes homogeneity of labeled observations with multiple label
#'  types.
#'
#' @param x input data matrix, with rows as observations and columns
#'  as features
#' @param labels a vector of labels for the observations. A label could
#'  be a type of the observation e.g cell type in single-cell data
#' @return A list with the following components:
#' \itemize{
#'  \item label_separability  A vector of separability scores for each
#'   of the label types. A high score denotes high separability
#'  \item overall_separability  Overall average separability score for
#'   all the labels
#' }
#'
#' @export
separability <- function(x,labels)
{

  if(missing(x)) stop("Argument x is required.")
  if(missing(labels)) stop("Argument labels is required.")
  if(nrow(x)!=length(labels)) stop("Length of labels does not match sample size of x")

  #Get unique labels from vector of labels
  unique_labels = unique(labels)

  #Paper tissue specificity
  label_purity = vector()
  edge_purity = vector()
  comb_purity = vector()

  tree_info = get_edges(x,"boruvka")
  tree = tree_info$tree


  for(i in unique_labels)
  {

    ###set of vertices for a unique label
    s = which(labels %in% i)

    ###set starting index to 0
    s = s-1

    ###Obtain minimum subtree cover of vertices in s
    res = minSubtreeCover(tree,s,labels)


    ###Vertices in s
    a = length(s)

    ###Label purity for each unique label (paper tissue specificity)
    label_purity[i] = a/res$subtree_nodes

  }

  tp = list()
  mst_edges = tree_info$edges

  #tissue specificity using original method used in the paper
   tp = list("label_separability"=label_purity, "overall_separability"= sum(label_purity)/length(unique_labels), "mst"=list("edges"=  mst_edges, "labels"=labels))


   class(tp)="treedim"

   return(tp)
}



make.tree <- function(x)
{
   dist = calcPairwiseDist(x)
   mtree = calculate_mst(dist)
  return(mtree)
}

#TDT on linear tree
x = rnorm(100)
y = x+1
linear = cbind(x,y)

test_that("Accuracy of tree dimension test (test.trajectory) statistics on linear MST", {
  expect_equal(test.trajectory(linear, MST="exact", dim.reduction = "none")$tdt_measure, 1)
  expect_equal(test.trajectory(linear, MST="exact", dim.reduction = "none")$tdt_effect, 1)
  expect_equal(test.trajectory(linear, MST="exact", dim.reduction = "none")$leaves, 2)
  expect_equal(test.trajectory(linear, MST="exact", dim.reduction = "none")$diameter, 99)
})


test_that("Accuracy of tree dimension test (compute.stats) statistics on linear MST", {
  expect_equal(compute.stats(linear, MST="exact", dim.reduction = "none")$tdt_measure, 1)
  expect_equal(compute.stats(linear, MST="exact", dim.reduction = "none")$tdt_effect, 1)
  expect_equal(compute.stats(linear, MST="exact", dim.reduction = "none")$leaves, 2)
  expect_equal(compute.stats(linear, MST="exact", dim.reduction = "none")$diameter, 99)
})


# Tdt on star tree
x = c(0,0,0,1,-1)
y = c(0,1,-1,0,0)
star = cbind(x,y)


test_that("Accuracy of tree dimension test (test.trajectory) statistics on star MST", {
  expect_equal(compute.stats(star, MST="exact", dim.reduction = "none")$tdt_measure, 2)
  expect_equal(compute.stats(star, MST="exact", dim.reduction = "none")$tdt_effect, 0)
  expect_equal(compute.stats(star, MST="exact", dim.reduction = "none")$leaves, 4)
  expect_equal(compute.stats(star, MST="exact", dim.reduction = "none")$diameter, 2)
})



##Dimension 2 case; TDT on dimension 2 tree
x = seq(from=0, to = 10, by=1)
y = rep(5,length(x))
mat = cbind(x,y)

mat = rbind(mat, cbind(rep(5,length(x)),x))
mat = mat[-6,]

test_that("Accuracy of tree dimension test (test.trajectory) statistics on linear MST", {
  expect_equal(compute.stats(mat, MST="boruvka", dim.reduction = "none")$tdt_measure, 2)
  expect_equal(compute.stats(mat, MST="boruvka", dim.reduction = "none")$tdt_effect, 0.699, tolerance=0.001)
  expect_equal(compute.stats(mat, MST="boruvka", dim.reduction = "none")$leaves, 4)
  expect_equal(compute.stats(mat, MST="boruvka", dim.reduction = "none")$diameter, 10)
})


test_that("Accuracy of tree dimension test (test.trajectory) statistics on linear MST", {
  expect_equal(compute.stats(mat, MST="boruvka", dim.reduction = "none")$tdt_measure, 2)
  expect_equal(compute.stats(mat, MST="boruvka", dim.reduction = "none")$tdt_effect, 0.699, tolerance=0.001)
  expect_equal(compute.stats(mat, MST="boruvka", dim.reduction = "none")$leaves, 4)
  expect_equal(compute.stats(mat, MST="boruvka", dim.reduction = "none")$diameter, 10)
})

#######Original tissue separability################
# completely separated
x = seq(from=1, to=20, by=1)
y = 0.1 * x * x
mat = cbind(x,y)
labels = c(rep("red",12), rep("blue",8))

test_that("Separability on linear completely separated MST", {
  res = separability(mat, labels=labels)
  expect_equal(unname(res$label_separability['red']), 1)
  expect_equal(unname(res$label_separability['blue']), 1)
  expect_equal(res$overall_separability, 1)
})



# Mixed, no adjacent samples with same label

x = seq(from=1, to=20, by=1)
y = 0.1 * x * x
mat = cbind(x,y)
labels = rep(c("red","blue"),10)

test_that("Separability on linear completely mixed MST", {
  res = separability(mat, labels=labels)
  expect_equal(unname(res$label_separability['red']), 10/19)
  expect_equal(unname(res$label_separability['blue']), 10/19)
  expect_equal(res$overall_separability, 10/19)
})




######Normalized tissue separability################

# x = seq(from=1, to=20, by=1)
# y = 0.1 * x * x
# mat = cbind(x,y)
# labels = c(rep("red",12), rep("blue",8))
#
# test_that("Separability on linear completely separated MST", {
#   res = separability(mat, labels=labels, method="normalized")
#   expect_equal(unname(res$label_separability['red']), 1)
#   expect_equal(unname(res$label_separability['blue']), 1)
#   expect_equal(res$overall_separability, 1)
# })
#
#
#
# # Mixed, no adjacent samples with same label
#
# x = seq(from=1, to=20, by=1)
# y = 0.1 * x * x
# mat = cbind(x,y)
# labels = rep(c("red","blue"),10)
#
# test_that("Separability on linear completely mixed MST", {
#   res = separability(mat, labels=labels, method="normalized")
#   expect_equal(unname(res$label_separability['red']), 0.1)
#   expect_equal(unname(res$label_separability['blue']), 0.1)
#   expect_equal(res$overall_separability, 0.1)
# })

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(warning = FALSE, message = FALSE,
  collapse = TRUE, cache = FALSE, comment = "#>", out.width = "65%")

## -----------------------------------------------------------------------------
require(TreeDimensionTest)

data_path=system.file('extdata', 'bifurcating_7.rds', package = 'TreeDimensionTest')

input = readRDS(data_path)

## -----------------------------------------------------------------------------
res = test.trajectory(input)

## ----echo=FALSE---------------------------------------------------------------
knitr::kable(unlist(res[-7], recursive = FALSE), col.names = "Test results contained in `res`")

## -----------------------------------------------------------------------------
plot(res, node.size=12, node.col="mediumseagreen", 
     main = paste0("Trajectory presence\np-value = ",
                   format.pval(res$p.value, digit=2)))
pc=prcomp(input)
plot(pc$x[,c(1:2)], xlab="PC1", ylab="PC2", cex=1,
     sub="Principal components", col="mediumseagreen",
     main = paste0("Trajectory presence\np-value = ",
                   format.pval(res$p.value, digit=2), 
                   "\n(n = ", nrow(input), ")")
    )

## -----------------------------------------------------------------------------
res = test.trajectory(input, dim.reduction = "pca", MST = "exact")

## ----echo=FALSE---------------------------------------------------------------
knitr::kable(unlist(res[-7], recursive = FALSE), col.names = "Test results contained in `res`")

## -----------------------------------------------------------------------------
n = 100
mat = cbind(rnorm(n), rnorm(n))
res = test.trajectory(mat, dim.reduction = "none")

## ----echo=FALSE---------------------------------------------------------------
knitr::kable(unlist(res[-7]), col.names = "Test results contained in `res`")

## -----------------------------------------------------------------------------
plot(res, node.size=12, 
     main = paste0("Trajectory presence\np-value = ",
                   format.pval(res$p.value, digit=2)))
plot(mat, col="orange", pch=2, cex=0.5, xlab="Dim 1", ylab="Dim 2",
     main=paste0("Trajectory presence\np-value = ", 
                format.pval(res$p.value, digit=2), 
                "\n(n = ", n, ")")
     )

## -----------------------------------------------------------------------------
res = compute.stats(mat, MST="boruvka", dim.reduction = "none")

## ----echo=FALSE---------------------------------------------------------------
knitr::kable(unlist(res[-5]), col.names = "Results contained in `res`")

## -----------------------------------------------------------------------------
#Random data
mat = cbind(rnorm(200), rnorm(200))

#Labels for the samples in the data
labels = c(rep("L1", 93), rep("L2",78), rep("L3",29))

#Color vector of samples, each unique color correspods with unique label
cols = c(rep("orange", 93), rep("mediumseagreen", 78), rep("purple", 29))

#Compute separability of samples in mat
res = separability(mat, labels)

## -----------------------------------------------------------------------------
knitr::kable(res$label_separability, col.names = "Label separability")

## -----------------------------------------------------------------------------
#Plots an MST of the data, with samples of the same label highlighted by same color
# plotTree(mat, labels, node.size = 12, node.col = cols, 
#   main = paste("Low seperability", format(res$overall_separability, digits = 3)), 
#   legend.cord=c(-2.1,0.9)
# )

plot(res,node.size = 12, node.col = cols, 
  main = paste("Low seperability", format(res$overall_separability, digits = 3)), legend.cord=c(-2.1,0.9))

## -----------------------------------------------------------------------------
mat = rbind(
  cbind(rnorm(93,mean=20), rnorm(93, mean=20)),
  cbind(rnorm(78,mean=5), rnorm(78,mean=5)),
  cbind(rnorm(29, mean=50), rnorm(29, mean=50)))
labels = c(rep("L1", 93), rep("L2",78), rep("L3",29))
res = separability(mat, labels)


## -----------------------------------------------------------------------------
knitr::kable(res$label_separability, col.names = " Label separability")

## -----------------------------------------------------------------------------
#Color vector of samples corresponding to labels
cols = c(rep("orange", 93), rep("mediumseagreen", 78), rep("purple", 29))

# plotTree(
#   mat,labels, node.size=12, node.col = cols, 
#   main = paste("High seperability", format(res$overall_separability, digits = 3)), 
#   legend.cord=c(-1.9,0.9))


plot(res,node.size = 12, node.col = cols, 
  main = paste("High seperability", format(res$overall_separability, digits = 3)), legend.cord=c(-2.1,0.9))

## -----------------------------------------------------------------------------
#Loading calcium signaling pathway data from Mouse
#This is Mouse development RNA-seq data spanned by the geneset fo calcium signaling pathway
#Rows are genes and columns are samples.

file.rdata=system.file('extdata', 'calcium_pathway_data.rdata', package = 'TreeDimensionTest')
load(file=file.rdata)

#loading color vector of samples by label type; mouse_cols
file.rdata=system.file('extdata', 'mouse_cols.rdata', package = 'TreeDimensionTest')
load(file=file.rdata)

#Labels of the samples are the column names of the data, which are names of tissue types.
labels = colnames(calcium_pathway_data)

res = separability(t(calcium_pathway_data), labels)

#Separabiltiy for each tissue type as well as the overall separability. High separability depicts high tissue specificity.


# plotTree(
#   t(calcium_pathway_data), labels, node.col=mouse_cols,node.size=12, 
#   main = paste("Calcium signaling pathway\nTissue specificity", 
#                format(res$overall_separability, digits = 3)), 
#   legend.cord=c(-1.9,-1.3))

plot(res,node.size = 12, node.col=mouse_cols,
 main = paste("Calcium signaling pathway\nTissue specificity", 
               format(res$overall_separability, digits = 3)), legend.cord=c(-1.9,-1.3))

## -----------------------------------------------------------------------------
knitr::kable(res$label_separability, col.names = "Calcium signaling pathway tissue specificity")

## -----------------------------------------------------------------------------
#Loading ribosome pathway data from Mouse
file.rdata=system.file('extdata', 'ribosome_pathway_data.rdata', package = 'TreeDimensionTest')
load(file=file.rdata)

#loading color vector of samples by label type; mouse_cols
file.rdata=system.file('extdata', 'mouse_cols.rdata', package = 'TreeDimensionTest')
load(file=file.rdata)

# ribsome_pathway_data is RNA-seq data with rows as genes and columns as samples
labels = colnames(ribosome_pathway_data)
res = separability(t(ribosome_pathway_data), labels)
plot(
  res, node.col= mouse_cols,
  node.size=12, 
  main = paste("Ribosome pathway\nTissue specificity",
               format(res$overall_separability, digits = 3)), 
  legend.cord=c(-1.9,-1.3))

## -----------------------------------------------------------------------------
knitr::kable(res$label_separability, col.names = "Ribosome pathway tissue specificity")

# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

calcPairwiseDist <- function(centers) {
    .Call('_TreeDimensionTest_calcPairwiseDist', PACKAGE = 'TreeDimensionTest', centers)
}

calculate_mst <- function(dist_mat) {
    .Call('_TreeDimensionTest_calculate_mst', PACKAGE = 'TreeDimensionTest', dist_mat)
}

get_longest_path_statistic <- function(tree) {
    .Call('_TreeDimensionTest_get_longest_path_statistic', PACKAGE = 'TreeDimensionTest', tree)
}

tree_dimension <- function(tree) {
    .Call('_TreeDimensionTest_tree_dimension', PACKAGE = 'TreeDimensionTest', tree)
}

to_adj_mat <- function(edges) {
    .Call('_TreeDimensionTest_to_adj_mat', PACKAGE = 'TreeDimensionTest', edges)
}

get_edges <- function(mat, MST) {
    .Call('_TreeDimensionTest_get_edges', PACKAGE = 'TreeDimensionTest', mat, MST)
}

getStatistics <- function(mat, sample_size, MST, returnTree) {
    .Call('_TreeDimensionTest_getStatistics', PACKAGE = 'TreeDimensionTest', mat, sample_size, MST, returnTree)
}

computeDists <- function(data, perm, sample_size, g, MST) {
    .Call('_TreeDimensionTest_computeDists', PACKAGE = 'TreeDimensionTest', data, perm, sample_size, g, MST)
}

minSubtreeCover <- function(tree, s, labels) {
    .Call('_TreeDimensionTest_minSubtreeCover', PACKAGE = 'TreeDimensionTest', tree, s, labels)
}

---
title: "Tutorial: Using the 'TreeDimensionTest' package"
output: rmarkdown::html_vignette
date: Updated March 11, 2022
bibliography: "`r system.file('REFERENCES.bib', package='TreeDimensionTest')`"
vignette: >
  %\VignetteIndexEntry{Tutorial: Using the 'TreeDimensionTest' package}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(warning = FALSE, message = FALSE,
  collapse = TRUE, cache = FALSE, comment = "#>", out.width = "65%")
```

## 1. Testing trajectory presence

The package provides a tool to statistically assess presence of trajectory in data. The function, `test.trajectory()`, implements the tree dimension test (TDT) [@Tenha:2022]. It takes as input a matrix with rows as observations and columns as features. The output from the function is a list containing the tree dimension test measure (TDT), tree dimension test effect, $S$ statistic and the p.value for TDT. 

### Example 1.1 Simulated single-cell data with trajectory presence

The example below illustrates the application of TDT to test presence of trajectory in simulated single-cell RNA-seq gene expression data that has a trajectory. The dataset is stored in matrix `input` [@dynverse_data], where rows are cells and columns are genes. TDT is able to recognize the presence of trajectory as depicted by the significant TDT $p$-value.
```{r}
require(TreeDimensionTest)

data_path=system.file('extdata', 'bifurcating_7.rds', package = 'TreeDimensionTest')

input = readRDS(data_path)
```

Next we run the test.trajectory function on matrix `input`, with the other parameters set to default.
```{r}
res = test.trajectory(input)
```


The test returns a list containing tree dimension measure (`tdt_measure`), effect (`tdt_effect`), test statistic, $p$-value, number vertices that are leaves, and tree diameter. Here, the $p$-value is significant and `tdt_effect` is strong, depicting presence of trajectory.
```{r echo=FALSE}
knitr::kable(unlist(res[-7], recursive = FALSE), col.names = "Test results contained in `res`")
```

We visualize the MST and the scatterplot using principal components.

```{r}
plot(res, node.size=12, node.col="mediumseagreen", 
     main = paste0("Trajectory presence\np-value = ",
                   format.pval(res$p.value, digit=2)))
pc=prcomp(input)
plot(pc$x[,c(1:2)], xlab="PC1", ylab="PC2", cex=1,
     sub="Principal components", col="mediumseagreen",
     main = paste0("Trajectory presence\np-value = ",
                   format.pval(res$p.value, digit=2), 
                   "\n(n = ", nrow(input), ")")
    )
```

Here we demonstrate using test.trajectory on the `input` matrix with modified parameter values.
`dim.reduction="pca"` means dimensionality reduction will be performed first using principal component analysis. The number of principal components is selected using the Scree test. One can set `dim.reduction="none"` if dimensionality reduction is unnecessary.
`MST="exact"`; the exact Euclidean MST (EMST) is used. The alternative is the approximate and fast dual-tree Boruvka algorithm by setting `MST="boruvka"` to obtain an approximate EMST.

```{r}
res = test.trajectory(input, dim.reduction = "pca", MST = "exact")
```
```{r echo=FALSE}
knitr::kable(unlist(res[-7], recursive = FALSE), col.names = "Test results contained in `res`")
```
It can be seen from the results that the exact MST and boruvka MST are equivalent for small sample size.

### Example 1.2 Simulated isotropic data without trajectory presence

We simulated spherical bivariate normal data, which are isotropic and contain no trajectory. The $p$-value for the test is insignificant.

```{r}
n = 100
mat = cbind(rnorm(n), rnorm(n))
res = test.trajectory(mat, dim.reduction = "none")
```

Test statistics and $p$-value are contained in `res`:
```{r echo=FALSE}
knitr::kable(unlist(res[-7]), col.names = "Test results contained in `res`")
```

We visualize the data which show no sign of trajectory presence.
```{r}
plot(res, node.size=12, 
     main = paste0("Trajectory presence\np-value = ",
                   format.pval(res$p.value, digit=2)))
plot(mat, col="orange", pch=2, cex=0.5, xlab="Dim 1", ylab="Dim 2",
     main=paste0("Trajectory presence\np-value = ", 
                format.pval(res$p.value, digit=2), 
                "\n(n = ", n, ")")
     )
```

### Calculating test statistics without $p$-value

TDT statistics can be calculated relatively quickly to learn if there is any effect in the data before launching the more time consuming step of calculating the $p$-value.

Function `compute.stats()` computes tree dimension measure, tree dimension effect, number of leafs and diameter of EMST for a given input data without calculating the $p$-value.

```{r}
res = compute.stats(mat, MST="boruvka", dim.reduction = "none")
```
```{r echo=FALSE}
knitr::kable(unlist(res[-5]), col.names = "Results contained in `res`")
```

## 2. Measuring data subset homogeneity by separability 

Function `separability()` computes heterogeneity of observations of the same type in a given data [@Tenha:2022]. Observations of the same type have the same label. The function takes a matrix as input with rows as observations and columns as features. The function also takes a vector of labels for the observations. The function returns separability values for each label type and the overall separability value. The separability values range from 0 to 1, with 1 being the highest separability.

### Example 2.1 Homogeneous data with low separability

In the examples below, there are three types of observations labeled L1, L2 and L3. An instance of real application is in single-cell data, where the labels could be cell types.

```{r}
#Random data
mat = cbind(rnorm(200), rnorm(200))

#Labels for the samples in the data
labels = c(rep("L1", 93), rep("L2",78), rep("L3",29))

#Color vector of samples, each unique color correspods with unique label
cols = c(rep("orange", 93), rep("mediumseagreen", 78), rep("purple", 29))

#Compute separability of samples in mat
res = separability(mat, labels)
```

The result is a list containing separability values for each label and, overall separability on the data. The overall separability is relatively low, implying samples with same labels are mixed.

```{r}
knitr::kable(res$label_separability, col.names = "Label separability")
```


```{r}
#Plots an MST of the data, with samples of the same label highlighted by same color
# plotTree(mat, labels, node.size = 12, node.col = cols, 
#   main = paste("Low seperability", format(res$overall_separability, digits = 3)), 
#   legend.cord=c(-2.1,0.9)
# )

plot(res,node.size = 12, node.col = cols, 
  main = paste("Low seperability", format(res$overall_separability, digits = 3)), legend.cord=c(-2.1,0.9))
```


### Example 2.2 Heterogeneous data with high separability

An example where samples with the same label are close together.

```{r}
mat = rbind(
  cbind(rnorm(93,mean=20), rnorm(93, mean=20)),
  cbind(rnorm(78,mean=5), rnorm(78,mean=5)),
  cbind(rnorm(29, mean=50), rnorm(29, mean=50)))
labels = c(rep("L1", 93), rep("L2",78), rep("L3",29))
res = separability(mat, labels)

```
The overall separability is 1, implying samples of different labels are perfectly separated.

```{r}
knitr::kable(res$label_separability, col.names = " Label separability")
```


```{r}
#Color vector of samples corresponding to labels
cols = c(rep("orange", 93), rep("mediumseagreen", 78), rep("purple", 29))

# plotTree(
#   mat,labels, node.size=12, node.col = cols, 
#   main = paste("High seperability", format(res$overall_separability, digits = 3)), 
#   legend.cord=c(-1.9,0.9))


plot(res,node.size = 12, node.col = cols, 
  main = paste("High seperability", format(res$overall_separability, digits = 3)), legend.cord=c(-2.1,0.9))
```

## 3. Understanding tissue specificity of pathway gene expression dynamics via separability

We now illustrate the use of separability to compute tissue specificity for calcium signaling and ribosome pathways on developing mouse data [@evodevo] with samples of different tissue types.

### Example 3.1 Tissue specificity of the calcium signaling pathway during development

```{r}
#Loading calcium signaling pathway data from Mouse
#This is Mouse development RNA-seq data spanned by the geneset fo calcium signaling pathway
#Rows are genes and columns are samples.

file.rdata=system.file('extdata', 'calcium_pathway_data.rdata', package = 'TreeDimensionTest')
load(file=file.rdata)

#loading color vector of samples by label type; mouse_cols
file.rdata=system.file('extdata', 'mouse_cols.rdata', package = 'TreeDimensionTest')
load(file=file.rdata)

#Labels of the samples are the column names of the data, which are names of tissue types.
labels = colnames(calcium_pathway_data)

res = separability(t(calcium_pathway_data), labels)

#Separabiltiy for each tissue type as well as the overall separability. High separability depicts high tissue specificity.


# plotTree(
#   t(calcium_pathway_data), labels, node.col=mouse_cols,node.size=12, 
#   main = paste("Calcium signaling pathway\nTissue specificity", 
#                format(res$overall_separability, digits = 3)), 
#   legend.cord=c(-1.9,-1.3))

plot(res,node.size = 12, node.col=mouse_cols,
 main = paste("Calcium signaling pathway\nTissue specificity", 
               format(res$overall_separability, digits = 3)), legend.cord=c(-1.9,-1.3))
```

Calcium signaling pathway has high tissue specificity as depicted by the high separability value. Tissues of the same type are closer together as shown in the plot.

```{r}
knitr::kable(res$label_separability, col.names = "Calcium signaling pathway tissue specificity")
```


### Example 3.2 Tissue specificity of the ribosome pathway during development

```{r}
#Loading ribosome pathway data from Mouse
file.rdata=system.file('extdata', 'ribosome_pathway_data.rdata', package = 'TreeDimensionTest')
load(file=file.rdata)

#loading color vector of samples by label type; mouse_cols
file.rdata=system.file('extdata', 'mouse_cols.rdata', package = 'TreeDimensionTest')
load(file=file.rdata)

# ribsome_pathway_data is RNA-seq data with rows as genes and columns as samples
labels = colnames(ribosome_pathway_data)
res = separability(t(ribosome_pathway_data), labels)
plot(
  res, node.col= mouse_cols,
  node.size=12, 
  main = paste("Ribosome pathway\nTissue specificity",
               format(res$overall_separability, digits = 3)), 
  legend.cord=c(-1.9,-1.3))
```

The ribosome pathway has relatively lower tissue specificity as depicted by the lower separability value. Tissues of the same type are mixed as shown in the plot.

```{r}
knitr::kable(res$label_separability, col.names = "Ribosome pathway tissue specificity")
```

# References

<div id="refs"></div>

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tree_dim.R
\name{plot.treedim}
\alias{plot.treedim}
\title{Visualizing Euclidean Minimum Spanning Trees}
\usage{
\method{plot}{treedim}(
  x,
  ...,
  node.col = "orange",
  node.size = 5,
  main = "MST plot",
  legend.cord = c(-1.2, 1.1)
)
}
\arguments{
\item{x}{An object of type "treedim"; returned from test.trajectory, compute.stats or separability}

\item{...}{ignore}

\item{node.col}{vector of colors for the observations in x (vertices)}

\item{node.size}{numerical value to represent size of nodes in the plot}

\item{main}{title for the plot}

\item{legend.cord}{vector of the xy coordinates for the legend c(x,y)}
}
\value{
result plots a minimum spanning tree for input data x
}
\description{
Plots an Euclidean minimum spanning tree from given input data.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tree_dim.R
\name{test.trajectory}
\alias{test.trajectory}
\title{Tree Dimension Test}
\usage{
test.trajectory(
  x,
  perm = 100,
  MST = c("boruvka", "exact"),
  dim.reduction = c("pca", "none")
)
}
\arguments{
\item{x}{matrix of input data. Rows as observations and columns as
features.}

\item{perm}{number of simulations to compute null distribution
parameters by maximum likelihood estimation.}

\item{MST}{the MST algorithm to be used in test. There are two
options: "exact" MST and "boruvka" which is approximate but faster
for large samples.}

\item{dim.reduction}{string parameter with value "pca" to perform
dimensionality reduction or "none" to not perform dimensionality
reduction before the test.}
}
\value{
A list with the following components:
\itemize{
 \item tdt_measure The tree dimension value for the given input data
 \item statistic  The S statistic calculated on the input data. S statistic is derived from tree dimension
 \item tdt_effect Effect size for tree dimension
 \item leaves Number of leaf/degree1 vertices in the MST  of the data
 \item diameter The tree diameter of MST, where each edge is of unit length
 \item p.value The pvalue for the S statistic. Pvalue measures presence of trajectory in input x.
 \item original_dimension If "pca" is selected, the number of dimensions in the original dataset
 \item pca_components If "pca" is selected, the number of pca components selected after dimensionality reduction
 \item mst A vector of edges of the mst computed on x. Length of vector is always even.
}
}
\description{
Computes the statistical significance for the presence of trajectory
in multivariate data.
}
\details{
If the input data is already after dimension reduction, use
\code{dim.reduction="none"}. The method is described in
\insertCite{Tenha:2022}{TreeDimensionTest}.
}
\references{
\insertAllCited{}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tree_dim.R
\name{empirical.distributions}
\alias{empirical.distributions}
\title{Empirical Null Distribution of Tree Dimension Test}
\usage{
empirical.distributions(rows, cols, perm = 100, MST = c("boruvka", "exact"))
}
\arguments{
\item{rows}{number of rows for data representing null case. Rows
represent sample size.}

\item{cols}{number of columns for data representing null case.
Columns represent variables.}

\item{perm}{number of simulations to compute null distribution.
Default is 100.}

\item{MST}{name of MST to be used in computing distribution. There
are two options; "exact" MST and "boruvka" which is faster for
large samples}
}
\value{
A list with the following components:
\itemize{
 \item dist       A vector with null distribution of s statistic
 \item meanlog    The meanlog parameter estimation for the lognormal distribution on empirical null distribution S.
 \item sdlog      The sdlog parameter estimation for lognormal distribution on empirical null distribution of S.
}
}
\description{
Computes empirical null distribution of S statistic and parameters
 for lognormal approximation for input of size rows * columns using
 multivariate normal randomization
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tree_dim.R
\name{compute.stats}
\alias{compute.stats}
\title{Tree Dimension Test Related Statistics}
\usage{
compute.stats(x, MST = c("boruvka", "exact"), dim.reduction = c("pca", "none"))
}
\arguments{
\item{x}{matrix of input data. Rows as observations and columns as features}

\item{MST}{name of MST to be used in test. There are 2 options; "exact" MST and "boruvka" which is faster for large samples}

\item{dim.reduction}{string parameter with value "pca" to perform dimensionality reduction or "none" to not perform dimensionality reduction}
}
\value{
A list with the following components:
\itemize{
 \item tdt_measure The tree dimension value for the given input data
 \item tdt_effect Effect size for tree dimension
 \item leaves Number of leaf/degree1 vertices in the MST  of the data
 \item diameter The tree diameter of MST, where each edge is of unit length
 \item original_dimension If "pca" is selected, the number of dimensions in the original dataset
 \item pca_components If "pca" is selected, the number of pca components selected after dimensionality reduction
 \item mst A vector of edges of the mst computed on x. Length of vector is always even.
 }
}
\description{
Computes tree dimension measure, tree dimension test effect,
number leafs and tree diameter from MST of a given dataset
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tree_dim.R
\name{separability}
\alias{separability}
\title{Separability of Labeled Data Points}
\usage{
separability(x, labels)
}
\arguments{
\item{x}{input data matrix, with rows as observations and columns
as features}

\item{labels}{a vector of labels for the observations. A label could
be a type of the observation e.g cell type in single-cell data}
}
\value{
A list with the following components:
\itemize{
 \item label_separability  A vector of separability scores for each
  of the label types. A high score denotes high separability
 \item overall_separability  Overall average separability score for
  all the labels
}
}
\description{
Computes homogeneity of labeled observations with multiple label
 types.
}
